==> haskell-ghc-exactprint-1.5.0-7-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-ghc-exactprint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ghc-exactprint
version:              1.5.0
visibility:           public
id:                   ghc-exactprint-1.5.0-HkZmtyTZhn35TmTrLq1lCu
key:                  ghc-exactprint-1.5.0-HkZmtyTZhn35TmTrLq1lCu
license:              BSD-3-Clause
maintainer:           alan.zimm@gmail.com
author:               Alan Zimmerman, Matthew Pickering
synopsis:             ExactPrint for GHC
description:
    Using the API Annotations available from GHC 9.2.1, this
    library provides a means to round trip any code that can
    be compiled by GHC, currently excluding lhs files.

    Note: requires GHC 9.2 or later. For GHC versions from
    7.10.2 to 9.0.* see this library with versions < 1.1

category:             Development
abi:                  61b6afa64179daa086781e53c2c13d2f
exposed:              True
exposed-modules:
    Language.Haskell.GHC.ExactPrint
    Language.Haskell.GHC.ExactPrint.Dump
    Language.Haskell.GHC.ExactPrint.ExactPrint
    Language.Haskell.GHC.ExactPrint.Lookup
    Language.Haskell.GHC.ExactPrint.Orphans
    Language.Haskell.GHC.ExactPrint.Parsers
    Language.Haskell.GHC.ExactPrint.Preprocess
    Language.Haskell.GHC.ExactPrint.Transform
    Language.Haskell.GHC.ExactPrint.Types
    Language.Haskell.GHC.ExactPrint.Utils

import-dirs:          /usr/lib/ghc-9.2.8/site-local/ghc-exactprint-1.5.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/ghc-exactprint-1.5.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghc-exactprint
hs-libraries:         HSghc-exactprint-1.5.0-HkZmtyTZhn35TmTrLq1lCu
depends:
    base-4.16.4.0 bytestring-0.11.4.0 containers-0.6.5.1
    data-default-0.7.1.1-LSJh75QrCu1H2SWBLBb1YB directory-1.3.6.2
    filepath-1.4.2.2 free-5.1.10-JX2XzUYKUFvAMV5GmwNZrb ghc-9.2.8
    ghc-boot-9.2.8 ghc-paths-0.1.0.12-KU8OzVy7s6GithbR4F0cp mtl-2.2.2
    ordered-containers-0.2.3-Ee6QR9weM8P1AVLTbz9WQP
    syb-0.7.2.4-3l4i7x4UWHaFMYIEmP3T6l

haddock-interfaces:
    /usr/share/doc/haskell-ghc-exactprint/html/ghc-exactprint.haddock

haddock-html:         /usr/share/doc/haskell-ghc-exactprint/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ghc-exactprint-1.5.0-19-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-ghc-exactprint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ghc-exactprint
version:              1.5.0
visibility:           public
id:                   ghc-exactprint-1.5.0-HXVoV4M5yQt8hu0DDQNuW5
key:                  ghc-exactprint-1.5.0-HXVoV4M5yQt8hu0DDQNuW5
license:              BSD-3-Clause
maintainer:           alan.zimm@gmail.com
author:               Alan Zimmerman, Matthew Pickering
synopsis:             ExactPrint for GHC
description:
    Using the API Annotations available from GHC 9.2.1, this
    library provides a means to round trip any code that can
    be compiled by GHC, currently excluding lhs files.

    Note: requires GHC 9.2 or later. For GHC versions from
    7.10.2 to 9.0.* see this library with versions < 1.1

category:             Development
abi:                  02563059453b1c3e8b0d6eafbcc97241
exposed:              True
exposed-modules:
    Language.Haskell.GHC.ExactPrint
    Language.Haskell.GHC.ExactPrint.Dump
    Language.Haskell.GHC.ExactPrint.ExactPrint
    Language.Haskell.GHC.ExactPrint.Lookup
    Language.Haskell.GHC.ExactPrint.Orphans
    Language.Haskell.GHC.ExactPrint.Parsers
    Language.Haskell.GHC.ExactPrint.Preprocess
    Language.Haskell.GHC.ExactPrint.Transform
    Language.Haskell.GHC.ExactPrint.Types
    Language.Haskell.GHC.ExactPrint.Utils

import-dirs:          /usr/lib/ghc-9.2.8/site-local/ghc-exactprint-1.5.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/ghc-exactprint-1.5.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghc-exactprint
hs-libraries:         HSghc-exactprint-1.5.0-HXVoV4M5yQt8hu0DDQNuW5
depends:
    base-4.16.4.0 bytestring-0.11.4.0 containers-0.6.5.1
    data-default-0.7.1.1-JYvfHll1aet2HYdPlRdwv9 directory-1.3.6.2
    filepath-1.4.2.2 free-5.1.10-GOblXT8Z2deK2DPOVW8Wt0 ghc-9.2.8
    ghc-boot-9.2.8 ghc-paths-0.1.0.12-KU8OzVy7s6GithbR4F0cp mtl-2.2.2
    ordered-containers-0.2.3-Ee6QR9weM8P1AVLTbz9WQP
    syb-0.7.2.4-4iiIjHgm67gJA1HTgFmr8s

haddock-interfaces:
    /usr/share/doc/haskell-ghc-exactprint/html/ghc-exactprint.haddock

haddock-html:         /usr/share/doc/haskell-ghc-exactprint/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
